@@ -15,12 +15,12 @@ Options:
 
 """
 
-from mobile_balance import mts, megafon
+from mobile_balance import mts, megafon, tele2
 from docopt import docopt
 
 
 def main():
-    arguments = docopt(__doc__, version='Mobile Balance 0.2.0')
+    arguments = docopt(__doc__, version='Mobile Balance 0.3.0')
     mobile_operator = globals()[arguments['<operator>']]
     print mobile_operator.get_balance(arguments['--phone'],
                                       arguments['--password'])
